//+------------------------------------------------------------------+
//| smileEAgle                                                       |
//| Copyright  2007, Shay Farber, www.strategybank.co.il            |
//| http://www.strategybank.co.il                                    |
//+------------------------------------------------------------------+

#property copyright "Copyright  2007, Shay Farber, www.strategybank.co.il"
#property link      "http://www.strategybank.co.il"

//+------------------------------------------------------------------------------------------------------------+
//| Version 0.01: 1. Basic implementation                                                                      |
//+------------------------------------------------------------------------------------------------------------+
//| Version 0.02: 1. Add Filters. pion                                                                         |
//+------------------------------------------------------------------------------------------------------------+

#define                 OBJECT_NAME_PATTERN     "SB_EAGLE_"   

//+------------------------------------------------------------------+
//| Parameters                                                       |
//+------------------------------------------------------------------+
extern string           Header.1                = " ---------------- Positions Parameters ---------------- ";
extern int              TakeProfit              = 20;
extern int              StopLoss                = 30;
extern string           Header.2                = " ------------------ Money Managment ------------------- ";
extern double           Lots                    = 1;
extern string           Header.3                = " ---------------- General Parameters ------------------ ";
extern double           Slippage                = 3;
extern string           Header.4                = " --------------  Break Out Parameters ----------------- ";
extern int              NumberOfDays            = 50;        
extern string           periodBegin             = "05:00"; 
extern string           periodEnd               = "08:00";   
extern string           BoxEnd                  = "23:00";
extern int              RangeFromBox            = 10;
extern bool             AutoAddSpread           = False;
extern bool             OnePerDay               = False;

//+------------------------------------------------------------------+
//| Variables                                                        |
//+------------------------------------------------------------------+
int                     MagicNumber             = 17070701;
int                     LastMode                = -1;
int                     LastDayOfWeek           = -1; 
int                     BoxBreakOut_Offset      = 0; 
bool                    OrderLong = False, OrderShort = False;
int                     TotalLong, TotalShort;

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int init()
{
   DeleteAllObjects();
   DrawLabels("WWW.STRATEGYBANK.CO.IL", 1);   
//----
   return(0);
}
  
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int deinit()
{
   DeleteAllObjects();   
//----
   return(0);
}

//+------------------------------------------------------------------+
//| Count the total Positions                                        |
//+------------------------------------------------------------------+
int CountTotal()
{
   TotalLong = 0; TotalShort = 0;
   for (int i = 0; i < OrdersTotal(); i++) 
   {
     OrderSelect(i, SELECT_BY_POS, MODE_TRADES);
     if ( OrderSymbol()==Symbol() && (OrderMagicNumber() == MagicNumber))
     {
        if (OrderType() == OP_BUY || OrderType() == OP_BUYSTOP)
        {
           TotalLong++;
        }
        if (OrderType() == OP_SELL || OrderType() == OP_SELLSTOP)
        {
           TotalShort++;
        }
     }
   }
   if (TotalLong == 0)
   {
      OrderLong = False;
   }
   if (TotalShort == 0)
   {
      OrderShort = False;
   }
      
   return(0);  
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void OpenLongPosition()
{
   double tp, sl, price, mLots;
   int ticket;
   
   price = Ask;
   
   if (Lots > 0)
      mLots = Lots;
   else
      mLots = 0.1;
   
   if (TakeProfit > 0)
      tp = price + TakeProfit * Point;
   else
      tp = 0;
      
   if (StopLoss > 0)
      sl = price - StopLoss * Point;
   else
      sl = 0;   
      
   ticket = OrderSend(Symbol(), OP_BUY, mLots, price, Slippage, sl, tp, NULL, MagicNumber, 0, Green);
   if (ticket > 0)
   {
      OrderLong = True;
      LastMode = OP_BUY;
      LastDayOfWeek = DayOfWeek();
   }
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void OpenShortPosition()
{
   double tp, sl, price, mLots;
   int ticket;
   
   price = Bid;
   
   if (Lots > 0)
      mLots = Lots;
   else
      mLots = 0.1;
         
   if (TakeProfit > 0)
      tp = price - TakeProfit * Point;
   else
      tp = 0;
      
   if (StopLoss > 0)
      sl = price + StopLoss * Point;
   else
      sl = 0;   

   ticket = OrderSend(Symbol(), OP_SELL, mLots, price, Slippage, sl, tp, NULL, MagicNumber, 0, Red);
   if (ticket > 0)
   {
      OrderShort = True;
      LastMode = OP_SELL;
      LastDayOfWeek = DayOfWeek();
   }
}

//+------------------------------------------------------------------+
//| Main Loop                                                        |
//+------------------------------------------------------------------+
int start()
{
   CountTotal();
   
   if ( AutoAddSpread )
      BoxBreakOut_Offset = (Ask - Bid) / Point;
  
   datetime dtTradeDate=TimeCurrent();
   string sTimeBegin = periodBegin;
   string sTimeEnd = periodEnd;
   string sTimeObjEnd = BoxEnd;
  
   //---- Find The High/Low for today
  
   datetime dtTimeBegin, dtTimeEnd, dtTimeObjEnd;
   double   dPriceHigh,  dPriceLow;
   int      iBarBegin,   iBarEnd;

   dtTimeBegin = StrToTime(TimeToStr(dtTradeDate, TIME_DATE) + " " + sTimeBegin);
   dtTimeEnd = StrToTime(TimeToStr(dtTradeDate, TIME_DATE) + " " + sTimeEnd);
   dtTimeObjEnd = StrToTime(TimeToStr(dtTradeDate, TIME_DATE) + " " + sTimeObjEnd);
      
   iBarBegin = iBarShift(NULL, 0, dtTimeBegin);
   iBarEnd = iBarShift(NULL, 0, dtTimeEnd);
   dPriceHigh = (High[Highest(NULL, 0, MODE_HIGH, iBarBegin-iBarEnd, iBarEnd)]) + BoxBreakOut_Offset * Point;
   dPriceLow = (Low [Lowest (NULL, 0, MODE_LOW , iBarBegin-iBarEnd, iBarEnd)]) - BoxBreakOut_Offset * Point;
  
   //---- Compute filters
   bool LongFilter = false;
   bool ShortFilter = false;
   int dema = 0;
   int wema = 0;
   int rsi50 =0;
   int FilterBitMap = 0;

   if(iMA(NULL,PERIOD_W1,200,0,MODE_EMA,PRICE_CLOSE,0) > Ask) wema = 1;   
   if(iMA(NULL,PERIOD_D1,200,0,MODE_EMA,PRICE_CLOSE,0) > Ask) dema = 1;
   if(iRSI(NULL,0,14,PRICE_CLOSE,0) > 50) rsi50 =1;

   FilterBitMap = 4*wema + 2*dema + rsi50;
   
   if ( FilterBitMap == 0 || FilterBitMap == 1 || FilterBitMap == 3 || FilterBitMap == 5 ) 
      LongFilter = true;
   else
      ShortFilter = true;   
   
   //---- Open Positions where there is a BreakOut
   if (OnePerDay == False)
   {
      if (Bid < dPriceLow && dPriceLow - Bid <= RangeFromBox * Point && OrderLong == False && OrderShort == False &&
         Low[1] > dPriceLow)
       if(ShortFilter) OpenShortPosition();
   
      if (Ask > dPriceHigh && Ask - dPriceHigh <= RangeFromBox * Point && OrderLong == False && OrderShort == False &&
         High[1] < dPriceHigh)      
       if(LongFilter) OpenLongPosition();
   }
   else
   {
      if (Bid < dPriceLow && dPriceLow - Bid <= RangeFromBox * Point && OrderLong == False && OrderShort == False && DayOfWeek() != LastDayOfWeek &&
         Low[1] > dPriceLow)
       if(ShortFilter) OpenShortPosition();
   
      if (Ask > dPriceHigh && Ask - dPriceHigh <= RangeFromBox * Point && OrderLong == False && OrderShort == False && DayOfWeek() != LastDayOfWeek &&
         High[1] < dPriceHigh)
       if(LongFilter) OpenLongPosition();
   }
  
//----
   return(0);
}

//+------------------------------------------------------------------+
//| Delete Objects                                                   |
//+------------------------------------------------------------------+
void DeleteAllObjects()
{     
   int objectCount = ObjectsTotal();
   for (int index = objectCount - 1; index >= 0; index--)
   {
      string objectName = ObjectName(index);
      if (StringSubstr(objectName, 0, StringLen(OBJECT_NAME_PATTERN)) == OBJECT_NAME_PATTERN)
         ObjectDelete(objectName);
   }   
}

//+------------------------------------------------------------------+
//| Draw Objects                                                     |
//+------------------------------------------------------------------+ 
double DrawLabels(string text, int lineIndex)
{
      string objName = OBJECT_NAME_PATTERN + lineIndex + "_Copyright";
      int xPos = 8;
      int yPos = lineIndex * 15;
      int cornerID = 1;
      ObjectDelete(objName);
      ObjectCreate(objName, OBJ_LABEL, 0, 0, 0);
      ObjectSet(objName, OBJPROP_CORNER, cornerID);
      ObjectSet(objName, OBJPROP_XDISTANCE, xPos);
      ObjectSet(objName, OBJPROP_YDISTANCE, yPos);
      ObjectSet(objName, OBJPROP_BACK, true);
      ObjectSetText(objName, text, 14, "Times", Orange);
}         